--[[	Detailed Durability - Inventory Info Lib
	by SDPhantom
	https://www.wowinterface.com/forums/member.php?u=34145
	https://www.curseforge.com/members/sdphantomgamer/projects	]]
--------------------------------------------------------------------------

local AddOn=select(2,...);

--------------------------
--[[	Constants	]]
--------------------------
AddOn.AlertToInventorySlotMapping={
	INVSLOT_HEAD;
	INVSLOT_SHOULDER;
	INVSLOT_CHEST;
	INVSLOT_WAIST;
	INVSLOT_LEGS;
	INVSLOT_FEET;
	INVSLOT_WRIST;
	INVSLOT_HAND;
	INVSLOT_MAINHAND;
	INVSLOT_OFFHAND;
	INVSLOT_RANGED;
};

local RangedTypeToAmmoSlotMap={
	[LE_ITEM_WEAPON_BOWS]		=INVSLOT_AMMO;
	[LE_ITEM_WEAPON_GUNS]		=INVSLOT_AMMO;
	[LE_ITEM_WEAPON_THROWN]		=INVSLOT_RANGED;
	[LE_ITEM_WEAPON_CROSSBOW]	=INVSLOT_AMMO;
};

--------------------------
--[[	Inventory API	]]
--------------------------
function AddOn.GetWeaponType(itemid)
	local _,_,_,_,_,typeid,subid=GetItemInfoInstant(itemid);
	return typeid==LE_ITEM_CLASS_WEAPON and subid or nil;
end

function AddOn.GetAmmoSlot(weapontype) return weapontype and RangedTypeToAmmoSlotMap[weapontype] or nil; end

function AddOn.GetEquippedAmmo()
	local itemid=GetInventoryItemID("player",INVSLOT_RANGED);
	if not itemid or itemid==0 then return nil,nil; end--	TBC Classic returns zero instead of nil

	local weapontype=AddOn.GetWeaponType(itemid);
	local slot=weapontype and RangedTypeToAmmoSlotMap[weapontype];
	if not slot then return nil,nil; end

	if slot~=INVSLOT_RANGED then
		itemid=GetInventoryItemID("player",slot);
		if not itemid or itemid==0 then return nil,nil; end--	TBC Classic returns zero instead of nil
	end
	return itemid,slot;
end

function AddOn.UsesDurabilityForAmmo(itemid)
	if AddOn.IsModernClient then return false;--	Modern WoW doesn't use ammo slots anymore
	elseif itemid then return not AddOn.IsVanillaClient and AddOn.GetWeaponType(itemid)==LE_ITEM_WEAPON_THROWN;--	Thrown weapons in TBC+ Classic use durability as ammo
	else return nil; end
end

function AddOn.IsInfiniteAmmo(itemid)
	if AddOn.IsModernClient then return true;--	Modern WoW doesn't use ammo slots anymore
	elseif itemid then return LE_EXPANSION_LEVEL_CURRENT>=(LE_EXPANSION_NORTHREND or 2) and AddOn.GetWeaponType(itemid)==LE_ITEM_WEAPON_THROWN;--	Thrown weapons in Wrath+ Classic no longer have durability
	else return nil; end
end
